# Generated by Django 5.2.6 on 2025-09-17 14:39

import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_microbiology",
            "0015_alter_historicalmicrobiology_device_created_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                default="",
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="user_created",
            field=django_audit_fields.fields.userfield.UserField(
                blank=True,
                default="",
                help_text="Updated by admin.save_model",
                max_length=50,
                verbose_name="user created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="user_modified",
            field=django_audit_fields.fields.userfield.UserField(
                blank=True,
                default="",
                help_text="Updated by admin.save_model",
                max_length=50,
                verbose_name="user modified",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                default="",
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="user_created",
            field=django_audit_fields.fields.userfield.UserField(
                blank=True,
                default="",
                help_text="Updated by admin.save_model",
                max_length=50,
                verbose_name="user created",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="user_modified",
            field=django_audit_fields.fields.userfield.UserField(
                blank=True,
                default="",
                help_text="Updated by admin.save_model",
                max_length=50,
                verbose_name="user modified",
            ),
        ),
    ]



# Generated by Django 5.2.6 on 2025-09-24 04:56

import django_revision.revision_field
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_microbiology",
            "0016_alter_historicalmicrobiology_device_created_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="blood_culture_organism_text",
            field=models.TextField(
                blank=True, default="", verbose_name="If growth positive, organism"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="tissue_biopsy_organism_text",
            field=models.TextField(
                blank=True, default="", verbose_name="If growth positive, organism"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="tissue_biopsy_report",
            field=models.TextField(
                blank=True, default="", verbose_name="Histopathoplogy report"
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="blood_culture_organism_text",
            field=models.TextField(
                blank=True, default="", verbose_name="If growth positive, organism"
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="tissue_biopsy_organism_text",
            field=models.TextField(
                blank=True, default="", verbose_name="If growth positive, organism"
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="tissue_biopsy_report",
            field=models.TextField(
                blank=True, default="", verbose_name="Histopathoplogy report"
            ),
        ),
    ]



# Generated by Django 5.2.6 on 2025-09-17 04:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_microbiology", "0013_alter_historicalmicrobiology_revision_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalmicrobiology",
            name="device_modified",
            field=models.CharField(
                blank=True, max_length=10, null=True, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="microbiology",
            name="device_modified",
            field=models.CharField(
                blank=True, max_length=10, null=True, verbose_name="Device modified"
            ),
        ),
    ]
